@@ -132,7 +132,10 @@ class Flow:
         """
         if self.outputs:
             for output in self.outputs:
-                output.extract_value(self.response)
+                if output.needs_response:
+                    output.extract_value_from_response(self.response)
+                elif output.plugins:
+                    output.value = output.function()
 
     def get_plugin_values(self, user: User) -> None:
         """Given a user, get the plugins' values from it.
