@@ -21,7 +21,7 @@ import logging
 import os
 import re
 from base64 import b64encode
-from typing import Callable, Dict, Optional
+from typing import Callable, Dict, List, Optional, Union
 
 import hy
 import requests
@@ -60,6 +60,7 @@ class Plugin:
     # Plugin flags
     NEEDS_USERDATA = 0x01
     NEEDS_RESPONSE = 0x02
+    DEPENDS_ON_OTHER_PLUGINS = 0x04
 
     def __init__(
         self,
@@ -91,17 +92,37 @@ class Plugin:
 
         """
         self.name = name
+        self.plugins: List["Plugin"] = []
         self.value: Optional[str] = value
         self.flags = flags
 
         self.function: Callable[..., Optional[str]]
 
-        if flags & Plugin.NEEDS_USERDATA:
+        if (flags & Plugin.NEEDS_USERDATA) and not function:
             self.function = self.extract_from_userdata
         else:
             self.function = function
 
-    def extract_value(
+    def get_value(
+        self,
+        userdata: Dict[str, str],
+    ) -> Optional[str]:
+        """Gets the value from the Plugin.
+
+        Depending on the Plugin's flags, extract and return its value.
+
+        Args:
+          userdata:
+            A dictionary with the user specific data.
+        """
+        if not self.needs_response:
+            if self.needs_userdata:
+                self.value = self.function(userdata)
+            else:
+                self.value = self.function()
+        return self.value
+
+    def extract_value_from_response(
         self,
         response: Optional[requests.models.Response],
     ) -> None:
@@ -116,35 +137,16 @@ class Plugin:
             An requests.models.Response object with the HTTP response.
 
         """
-        if self.needs_response:
-            output = self.function(response)
-            if output:
-                self.value = output
-                logging.debug(
-                    "Found ouput %s = %s",
-                    self.name,
-                    self.value,
-                )
-            else:
-                logging.warning("Couldn't extract output: %s", str(self.name))
-
-    def get_value(
-        self,
-        userdata: Dict[str, str],
-    ) -> Optional[str]:
-        """Gets the value from the Plugin.
-
-        Depending on the Plugin's flags, extract and return its value.
-
-        Args:
-          userdata:
-            A dictionary with the user specific data.
-        """
-        if self.needs_userdata:
-            self.value = self.function(userdata)
-        elif not self.needs_response:
-            self.value = self.function()
-        return self.value
+        output = self.function(response)
+        if output:
+            self.value = output
+            logging.debug(
+                "Found ouput %s = %s",
+                self.name,
+                self.value,
+            )
+        else:
+            logging.warning("Couldn't extract output: %s", str(self.name))
 
     def extract_from_userdata(
         self, data: Dict[str, str] = None
@@ -185,6 +187,11 @@ class Plugin:
         """Returns True if the NEEDS_RESPONSE flag is set."""
         return bool(self.flags & self.NEEDS_RESPONSE)
 
+    @property
+    def depends_on_other_plugins(self) -> bool:
+        """Returns True if the DEPENDS_ON_OTHER_PLUGINS flag is set."""
+        return bool(self.flags & self.DEPENDS_ON_OTHER_PLUGINS)
+
 
 class Regex(Plugin):
     """Plugin to extract something using regular expressions.
@@ -393,7 +400,13 @@ class Json(Plugin):
 
     """
 
-    def __init__(self, name: str, extract: str) -> None:
+    def __init__(
+        self,
+        name: str,
+        extract: str,
+        function: Callable[[str], Optional[str]] = None,
+        flags: int = Plugin.NEEDS_RESPONSE,
+    ) -> None:
         """Initializes the Json Plugin.
 
         Creates the Json Plugin and extracts the specified field.
@@ -404,16 +417,28 @@ class Json(Plugin):
           extract:
             A string with the location of the JSON field to extract.
         """
-        super().__init__(
-            name=name,
-            function=self.extract_json_field,
-            flags=Plugin.NEEDS_RESPONSE,
-        )
+        if not function:
+            super().__init__(
+                name=name,
+                function=self.extract_json_from_response,
+                flags=flags,
+            )
+        else:
+            super().__init__(
+                name=name,
+                function=function,
+                flags=flags,
+            )
+
         self.extract = extract
 
-    def extract_json_field(
+    def extract_json_from_response(
         self, response: requests.models.Response
     ) -> Optional[str]:
+        """Extracts the json field from a HTTP response."""
+        return self.extract_json_field(response.text)
+
+    def extract_json_field(self, text: str) -> Optional[str]:
         """Extracts the JSON field from the text.
 
         Given the JSON body as a string, extract the field and store it
@@ -428,7 +453,7 @@ class Json(Plugin):
           found None will be returned.
 
         """
-        data = json.loads(response.text)
+        data = json.loads(text)
 
         json_filter = parse_json_filter(self.extract)
         is_valid = True
@@ -469,6 +494,18 @@ class Json(Plugin):
 
         return self.value
 
+    @classmethod
+    def from_plugin(cls, plugin: Plugin, name: str, extract: str) -> "Json":
+        """Extracts the JSON field from another plugin's value."""
+        json_plugin = cls(
+            name=name,
+            extract=extract,
+            flags=Plugin.DEPENDS_ON_OTHER_PLUGINS,
+        )
+        json_plugin.plugins = [plugin]
+        json_plugin.function = json_plugin.extract_json_field
+        return json_plugin
+
     def __str__(self) -> str:
         """Returns a string representation of the Plugin."""
         return "Json:" + str(self.extract)
@@ -494,7 +531,7 @@ class Variable(Plugin):
         """
         super().__init__(
             name=name,
-            function=lambda: self.value,
+            function=lambda data: data[self.name],
             flags=Plugin.NEEDS_USERDATA,
         )
 
@@ -640,7 +677,7 @@ class Cookie(Plugin):
         return str({self.name: self.value})
 
     @classmethod
-    def from_plugin(cls, name: str, plugin: Plugin) -> "Cookie":
+    def from_plugin(cls, plugin: Plugin, name: str) -> "Cookie":
         """Creates a Cookie from a Plugin.
 
         Given another :class:`plugin <raider.plugins.Plugin>`, and a
@@ -658,7 +695,7 @@ class Cookie(Plugin):
         """
         cookie = cls(
             name=name,
-            value=None,
+            value=plugin.value,
             function=lambda: plugin.value if plugin.value else None,
             flags=0,
         )
@@ -776,7 +813,7 @@ class Header(Plugin):
         return header
 
     @classmethod
-    def from_plugin(cls, name: str, plugin: Plugin) -> "Header":
+    def from_plugin(cls, plugin: Plugin, name: str) -> "Header":
         """Creates a Header from a Plugin.
 
         Given another :class:`plugin <raider.plugins.Plugin>`, and a
@@ -817,7 +854,9 @@ class Alter(Plugin):
     """
 
     def __init__(
-        self, plugin: Plugin, alter_function: Callable[[str], Optional[str]]
+        self,
+        plugin: Plugin,
+        alter_function: Callable[[str], Optional[str]],
     ) -> None:
         """Initializes the Alter Plugin.
 
@@ -830,33 +869,27 @@ class Alter(Plugin):
           alter_function:
             The Function with instructions on how to alter the value.
         """
-        self.alter_function = alter_function
         super().__init__(
             name=plugin.name,
             value=plugin.value,
-            # Get plugin's value from userdata since it has
-            # already been extracted from the original plugin.
-            flags=Plugin.NEEDS_USERDATA,
+            flags=Plugin.DEPENDS_ON_OTHER_PLUGINS,
             function=self.process_value,
         )
+        self.plugins = [plugin]
+        self.alter_function = alter_function
 
-    def process_value(self, data: Dict[str, str] = None) -> Optional[str]:
+    def process_value(self) -> Optional[str]:
         """Process the original plugin's value.
 
-        Get the value of the original's plugin from userdata, and give
-        it to ``alter_function``. Return the processed value and store
-        it in self.value.
-
-        Args:
-          data:
-            A dictionary with the userdata where the original plugin's
-            value should be found.
+        Gives the original plugin's value to ``alter_function``. Return
+        the processed value and store it in self.value.
 
         Returns:
           A string with the processed value.
+
         """
-        if data and self.name in data:
-            self.value = self.alter_function(data[self.name])
+        if self.plugins[0].value:
+            self.value = self.alter_function(self.plugins[0].value)
 
         return self.value
 
@@ -873,3 +906,48 @@ class Alter(Plugin):
         alter = cls(plugin=plugin, alter_function=lambda value: value + string)
 
         return alter
+
+
+class Combine(Plugin):
+    """Plugin to combine the values of other plugins."""
+
+    def __init__(self, *args: Union[str, Plugin]):
+        """Initialize Combine object."""
+        self.args = args
+        name = str(sum(hash(item) for item in args))
+        super().__init__(
+            name=name,
+            flags=Plugin.DEPENDS_ON_OTHER_PLUGINS,
+            function=self.concatenate_values,
+        )
+        self.plugins = []
+        for item in args:
+            if isinstance(item, Plugin):
+                self.plugins.append(item)
+
+    def concatenate_values(self) -> str:
+        """Concatenate the provided values.
+
+        This function will concatenate the arguments values. Accepts
+        both strings and plugins.
+
+        """
+        combined = ""
+        for item in self.args:
+            if isinstance(item, str):
+                combined += item
+            elif item.value:
+                combined += item.value
+        return combined
+
+
+class Empty(Plugin):
+    """Empty plugin to use for fuzzing new data."""
+
+    def __init__(self, name: str):
+        """Initialize Empty plugin."""
+        super().__init__(
+            name=name,
+            flags=0,
+            function=self.return_value,
+        )
