@@ -19,6 +19,8 @@
 
 import logging
 import sys
+import urllib
+from copy import deepcopy
 from typing import Any, Dict, List, Optional, Union
 from urllib import parse
 
@@ -160,26 +162,46 @@ class Request:
 
     def list_inputs(self) -> Optional[Dict[str, Plugin]]:
         """Returns a list of request's inputs."""
+
+        def get_children_plugins(plugin: Plugin) -> Dict[str, Plugin]:
+            """Returns the children plugins.
+
+            If a plugin has the flag DEPENDS_ON_OTHER_PLUGINS set,
+            return a dictionary with each plugin associated to its name.
+
+            """
+            output = {}
+            if plugin.depends_on_other_plugins:
+                for item in plugin.plugins:
+                    output.update({item.name: item})
+            return output
+
         inputs = {}
 
         if isinstance(self.url, Plugin):
             inputs.update({self.url.name: self.url})
+            inputs.update(get_children_plugins(self.url))
         if isinstance(self.path, Plugin):
             inputs.update({self.path.name: self.path})
+            inputs.update(get_children_plugins(self.path))
 
         for name in self.cookies:
             cookie = self.cookies[name]
             inputs.update({name: cookie})
+            inputs.update(get_children_plugins(cookie))
 
         for name in self.headers:
             header = self.headers[name]
             inputs.update({name: header})
+            inputs.update(get_children_plugins(header))
 
         for key, value in self.data.items():
             if isinstance(key, Plugin):
                 inputs.update({key.name: key})
+                inputs.update(get_children_plugins(key))
             if isinstance(value, Plugin):
                 inputs.update({value.name: value})
+                inputs.update(get_children_plugins(value))
 
         return inputs
 
@@ -286,9 +308,15 @@ class Request:
         logging.debug("Data: %s", str(data))
 
         if self.method == "GET":
+            # Encode special characters. This will replace "+" signs with "%20"
+            # in URLs. For some reason mypy doesn't like this, so typing will
+            # be ignored for this line.
+            params = urllib.parse.urlencode(
+                data, quote_via=urllib.parse.quote
+            )  # type: ignore
             req = requests.get(
                 self.url,
-                params=data,
+                params=params,
                 headers=headers,
                 cookies=cookies,
                 proxies=proxies,
@@ -328,3 +356,75 @@ class Request:
         logging.critical("Method %s not allowed", self.method)
         sys.exit()
         return None
+
+
+class Template(Request):
+    """Template class to hold requests.
+
+    It will initiate itself with a :class:`Request
+    <raider.request.Request>` parent, and when called will return a
+    copy of itself with the modified parameters.
+
+    """
+
+    def __init__(
+        self,
+        method: str,
+        url: Optional[Union[str, Plugin]] = None,
+        path: Optional[Union[str, Plugin]] = None,
+        cookies: Optional[List[Cookie]] = None,
+        headers: Optional[List[Header]] = None,
+        data: Optional[Union[Dict[Any, Any], PostBody]] = None,
+    ) -> None:
+        """Initializes the template object."""
+        super().__init__(
+            method=method,
+            url=url,
+            path=path,
+            cookies=cookies,
+            headers=headers,
+            data=data,
+        )
+
+    def __call__(
+        self,
+        url: Optional[Union[str, Plugin]] = None,
+        path: Optional[Union[str, Plugin]] = None,
+        cookies: Optional[List[Cookie]] = None,
+        headers: Optional[List[Header]] = None,
+        data: Optional[Union[Dict[Any, Any], PostBody]] = None,
+    ) -> "Template":
+        """Allow the object to be called.
+
+        Accepts the same arguments as the :class:`Request
+        <raider.request.Request>` class. When called, will return a copy
+        of itself with the modified parameters.
+
+        """
+        if bool(url) & bool(path):
+            logging.critical(
+                "One and only one of :path and :url parameters allowed"
+            )
+            sys.exit()
+
+        template = deepcopy(self)
+
+        if url:
+            template.url = url
+        if path:
+            template.path = path
+
+        if cookies:
+            for cookie in cookies:
+                template.cookies.set(cookie)
+
+        if headers:
+            for header in headers:
+                template.headers.set(header)
+        if data:
+            if isinstance(data, PostBody):
+                template.data.update(data.to_dict())
+            else:
+                template.data.update(data)
+
+        return template
