@@ -142,9 +142,11 @@ def import_raider_objects() -> Dict[str, Any]:
             "Command "
             "Plugin "
             "Alter "
+            "Combine "
+            "Empty "
         ),
         "flow": "Flow",
-        "request": "Request PostBody",
+        "request": "Request PostBody Template",
         "operations": (
             "Http " "Grep " "Print " "Error " "NextStage " "Operation " "Save "
         ),
